@@ -1,7 +1,6 @@
 package MooX::Keyword;
-use 5.006; use strict; use warnings; our $VERSION = '0.02'; 
+use 5.006; use strict; use warnings; our $VERSION = '0.03'; 
 use MooX::ReturnModifiers; use Anonymous::Object;
-use feature qw/state/;
 
 sub import {
 	my ( $package, %import ) = (shift, ref $_[0] ? %{ $_[0] } : @_);
@@ -46,7 +45,7 @@ MooX::Keyword - The great new MooX::Keyword!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -90,7 +89,7 @@ Quick summary of what the module does.
 	package Night 
 
 	use Moo;
-	use MooX::Keyword extends => Moon;
+	use MooX::Keyword extends => "Moon";
 
 	star polaris  => (
 		is => 'ro'
